==> skill-core-0.0.8-sources.jar: com/ptteng/common/skill/service/UserService.java <==
package com.ptteng.common.skill.service;

import java.util.List;
import java.util.Map;

import org.osoa.sca.annotations.Remotable;

import com.ptteng.common.skill.model.User;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;

@Remotable
public interface UserService extends BaseDaoService {


    public Long insert(User user) throws ServiceException, ServiceDaoException;


    public List<User> insertList(List<User> userList) throws ServiceException, ServiceDaoException;


    public boolean delete(Long id) throws ServiceException, ServiceDaoException;


    public boolean update(User user) throws ServiceException, ServiceDaoException;


    public boolean updateList(List<User> userList) throws ServiceException, ServiceDaoException;


    public User getObjectById(Long id) throws ServiceException, ServiceDaoException;


    public List<User> getObjectsByIds(List<Long> ids) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public Long getUserIdByMobile(String mobile) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getUserIds(Integer start, Integer limit)
            throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public Integer countUserIds() throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public Long getUserIdByNick(String nick) throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public Long getOnlineTeacherIdByOid(Long oid) throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public Long getOfflineTeacherIdByOid(Long oid) throws ServiceException, ServiceDaoException;


    public Long getUserIdByTypeAndOidAndNum(String type, Long oid, Integer num) throws ServiceException, ServiceDaoException;


    public Long getUserIdByFuzzyMatchMobile(String mobile) throws ServiceException, ServiceDaoException;

}

==> skill-core-1.12.1-sources.jar: com/ptteng/common/skill/service/UserService.java <==
package com.ptteng.common.skill.service;

import java.util.List;
import java.util.Map;

import org.osoa.sca.annotations.Remotable;

import com.ptteng.common.skill.model.User;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;

@Remotable
public interface UserService extends BaseDaoService {


    public Long insert(User user) throws ServiceException, ServiceDaoException;


    public List<User> insertList(List<User> userList) throws ServiceException, ServiceDaoException;


    public boolean delete(Long id) throws ServiceException, ServiceDaoException;


    public boolean update(User user) throws ServiceException, ServiceDaoException;


    public boolean updateList(List<User> userList) throws ServiceException, ServiceDaoException;


    public User getObjectById(Long id) throws ServiceException, ServiceDaoException;


    public List<User> getObjectsByIds(List<Long> ids) throws ServiceException, ServiceDaoException;

    public List<Long> getIdsByEntranceVideoAndGraduatedVideo(String entranceVideo,String graduatedVideo, Integer start, Integer limit) throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public Long getUserIdByMobile(String mobile) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getUserIds(Integer start, Integer limit)
            throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public Integer countUserIds() throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public Long getUserIdByNick(String nick) throws ServiceException, ServiceDaoException;


    public Long getUserIdByTypeAndOidAndNum(String type, Long oid, Integer num) throws ServiceException, ServiceDaoException;


    public Long getUserIdByFuzzyMatchMobile(String mobile) throws ServiceException, ServiceDaoException;

    public List<Long> getTeacherIdsByOid(Long oid, Integer start, Integer limit) throws ServiceException, ServiceDaoException;
    public List<Long> getUIdsByCid(Long cid, Integer start, Integer limit) throws ServiceException, ServiceDaoException;
    public Long getUserIdByInviteCode(String invitationCode) throws ServiceException, ServiceDaoException;
    public List<Long> getUIdsByRecommendId(Long recommendId, Integer start, Integer limit) throws ServiceException, ServiceDaoException;
    public List<Long> getIdsByOidAndIdentity(Long oid,Integer identity, Integer start, Integer limit) throws ServiceException, ServiceDaoException;

}
